==> v0.1.zip: cowsay-cows/README.md <==
# cowsay-cows

cowfiles in the original spirit of cowsay, except that all of these are
  actually bovine

## Examples

### bell

```plaintext
 _______________________________________
/ The hills are alive with the sound of \
\ moo-sic                               /
 ---------------------------------------
        \   ^__^
         \  (oo)
           /(__)\
          /      \
          |      |
          |      |
         /        \
        /__________\
             \\
             (_)
          Cow Bell
```

### birdstale

```plaintext
 _______________________________________
/ Grandpa said there was a moral there, \
| but you had to figure it out for      |
\ yourself                              /
 ---------------------------------------
        \   ^__^
         \  (oo)\___________*
            (__)\       )
                ||----w |  >o_
                ||     || /****\
```

### bull

```plaintext
 ______________________
< Actually, I'm a bull >
 ----------------------
        \   (__)
         \  |oo|\_______
            (__)\       )\
                ||---,- | *
                ||     ||
```

### compucow

```plaintext
 _______________________________________
/ The programmers number one excuse for \
\ slacking off: cow-pie-ling            /
 ---------------------------------------
        \
         \
           ^__^
         /   oo      ______
        |  /\_|     |      \
        |  |___     |       |
        |   ---@    |_______|
     *  |  |   ----   |    |
      \ |  |_____
       \|________|

          CompuCow
```

### cownterfeit

```plaintext
 ________________________________________
/ The love of moo-lah is the root of all \
\ evil                                   /
 ----------------------------------------
                             \
                              \
 ____________________________________________________________________
|      ________________________________________________________      |
|  10 )   T H E  U N I T E D  S T A T E S  O F  A M E R I C A  ( 10  |
|   /        ...........         ____                            \   |
|  |                           /      \         A10806726C        |  |
|  |      1      (A)          |  (__)  |    ___ __   __    1      |  |
|  |                          |  (oo)  |     | |_  |\ |           |  |
|  |         A10806726C       |  (__)  |     | |__ | \|           |  |
|  |      1  ..........        \//  /\/      ...........   1      |  |
|   \        .........     _______________     ........          /   |
|  10 )___________________/  TEN DOLLARS  \____________________( 10  |
|____________________________________________________________________|
                             Cownterfeit
```

### cowpooling

```plaintext
 _______________________________________
/ Maybe Al Gore will forgive us for all \
\ those methane emissions this way      /
 ---------------------------------------
        \
         \
        ___________________________
       | (__)  (__)  (__)   (__)  |
       | ( oo  ( oo  ( oo   ( oo  |
_______| /\_|  /\_|  /\_|   /\_|  |________
|                                         |
|   _____                        _____    |
|___|   |________________________|   |____|
    |___|                        |___|
```

### cowstruction

```plaintext
 _________________________________
< My favorite part is bull-dozing >
 ---------------------------------
                    \
   o==+--            \
   |  |\ \            \
   |  | \ \    ____________________
   |   \ \ \   |                  |
   |    \ \ \  |  +------------+  |
   |     \ \ \ |  |     ^__^   |  |
   |      \ \ \|  |     (oo)   |  |
   |       \ \ |  | o\  (__)   |  |
   |        \ \|  | | \/    \  |  |
 /---\       \ |  +------------+  |
/     \       \|                  |
|     |        |                  |
\     /        |                  |
 \---/         |                  |
               |                  |
            --------------------------
           (                          )
            --------------------------
          Cow-struction worker
```

### longhorn

```plaintext
 _______________________________________
/ I've been sent to spread the message: \
\ God bless Texas!                      /
 ---------------------------------------
   \
    \   \          /
     \   \________/
      \     |oo|\_________
            (__)\        )\
                ||----,- | *
                ||      ||

        Texas Longhorn Steer
```

### papal

```plaintext
 ________________________
< I forgive you, my calf >
 ------------------------
    \        _
     \      / \
      \    | + |
       \   |___|
        \  |o o|\_________
           (___)\     ^  )\
                |        | |
                ||----,- | *
                ||      ||

                Papal Bull
```

### pie

```plaintext
 ___________________________________
< Nobody makes them like Aunt Aggie >
 -----------------------------------
        \ 
         \  (__)
      ______(oo)_____
     ( _)_______(__) )
       \ __________/
         Cow Pie
```

### resting

```plaintext
 ______________________________________
( Insert deep thoughts and ruminations )
( here                                 )
 --------------------------------------
            o  ^__^
             o (oo)
       /-------(__)
      / \ |      \__
     *  /__-------__|
           ~     ~
       Cow resting
```

### super

```plaintext
 ________________________________________
/ If Impossible is as good as beef, then \
\ Bizarro is as good as me               /
 ----------------------------------------
     \
      \   ^__^    /^^^^^^^^/
       \  (oo)  //^^^^^^^^/
          (__)\/_______/-----*
       ^______/ ___    \_______^
       ^_____/\ \S/    /--------^
               \______/	 
       
       It's a bird...
        It's a plane...
```

==> v0.2.zip: cowsay-cows/README.md <==
# cowsay-cows

cowfiles in the original spirit of cowsay, except that all of these are actually bovine

Install using [Antigen](https://github.com/zsh-users/antigen)

```bash
antigen bundle millironx/cowsaycows
```

## Examples

### bell

```shellsession
$ cowsay -f bell
 _______________________________________
/ The hills are alive with the sound of \
\ moo-sic                               /
 ---------------------------------------
        \   ^__^
         \  (oo)
           /(__)\
          /      \
          |      |
          |      |
         /        \
        /__________\
             \\
             (_)
          Cow Bell
```

### birdstale

```shellsession
$ cowsay -f birdstale
 _______________________________________
/ Grandpa said there was a moral there, \
| but you had to figure it out for      |
\ yourself                              /
 ---------------------------------------
        \   ^__^
         \  (oo)\___________*
            (__)\       )
                ||----w |  >o_
                ||     || /****\
```

### bull

```shellsession
$ cowsay -f bull
 ______________________
< Actually, I'm a bull >
 ----------------------
        \   (__)
         \  |oo|\_______
            (__)\       )\
                ||---,- | *
                ||     ||
```

**BONUS**: aliased to `bullsay`

### compucow

```shellsession
$ cowsay -f compucow
 _______________________________________
/ The programmers number one excuse for \
\ slacking off: cow-pie-ling            /
 ---------------------------------------
        \
         \
           ^__^
         /   oo      ______
        |  /\_|     |      \
        |  |___     |       |
        |   ---@    |_______|
     *  |  |   ----   |    |
      \ |  |_____
       \|________|

          CompuCow
```

### cownterfeit

```shellsession
$ cowsay -f cownterfeit
 ________________________________________
/ The love of moo-lah is the root of all \
\ evil                                   /
 ----------------------------------------
                             \
                              \
 ____________________________________________________________________
|      ________________________________________________________      |
|  10 )   T H E  U N I T E D  S T A T E S  O F  A M E R I C A  ( 10  |
|   /        ...........         ____                            \   |
|  |                           /      \         A10806726C        |  |
|  |      1      (A)          |  (__)  |    ___ __   __    1      |  |
|  |                          |  (oo)  |     | |_  |\ |           |  |
|  |         A10806726C       |  (__)  |     | |__ | \|           |  |
|  |      1  ..........        \//  /\/      ...........   1      |  |
|   \        .........     _______________     ........          /   |
|  10 )___________________/  TEN DOLLARS  \____________________( 10  |
|____________________________________________________________________|
                             Cownterfeit
```

### cowpooling

```shellsession
$ cowsay -f cowpooling
 _______________________________________
/ Maybe Al Gore will forgive us for all \
\ those methane emissions this way      /
 ---------------------------------------
        \
         \
        ___________________________
       | (__)  (__)  (__)   (__)  |
       | ( oo  ( oo  ( oo   ( oo  |
_______| /\_|  /\_|  /\_|   /\_|  |________
|                                         |
|   _____                        _____    |
|___|   |________________________|   |____|
    |___|                        |___|
```

### cowstruction

```shellsession
$ cowsay -f cowstruction
 _________________________________
< My favorite part is bull-dozing >
 ---------------------------------
                    \
   o==+--            \
   |  |\ \            \
   |  | \ \    ____________________
   |   \ \ \   |                  |
   |    \ \ \  |  +------------+  |
   |     \ \ \ |  |     ^__^   |  |
   |      \ \ \|  |     (oo)   |  |
   |       \ \ |  | o\  (__)   |  |
   |        \ \|  | | \/    \  |  |
 /---\       \ |  +------------+  |
/     \       \|                  |
|     |        |                  |
\     /        |                  |
 \---/         |                  |
               |                  |
            --------------------------
           (                          )
            --------------------------
          Cow-struction worker
```

### longhorn

```shellsession
$ cowsay -f longhorn
 _______________________________________
/ I've been sent to spread the message: \
\ God blessed Texas!                    /
 ---------------------------------------
   \
    \   \          /
     \   \________/
      \     |oo|\_________
            (__)\        )\
                ||----,- | *
                ||      ||

        Texas Longhorn Steer
```

**BONUS**: aliased to `steersay`

### papal

```shellsession
$ cowsay -f papal
 ________________________
< I forgive you, my calf >
 ------------------------
    \        _
     \      / \
      \    | + |
       \   |___|
        \  |o o|\_________
           (___)\     ^  )\
                |        | |
                ||----,- | *
                ||      ||

                Papal Bull
```

### pie

```shellsession
$ cowsay -f pie
 ___________________________________
< Nobody makes them like Aunt Aggie >
 -----------------------------------
        \ 
         \  (__)
      ______(oo)_____
     ( _)_______(__) )
       \ __________/
         Cow Pie
```

### resting

```shellsession
$ cowthink -f resting
 ______________________________________
( Insert deep thoughts and ruminations )
( here                                 )
 --------------------------------------
            o  ^__^
             o (oo)
       /-------(__)
      / \ |      \__
     *  /__-------__|
           ~     ~
       Cow resting
```

### super

```shellsession
$ cowsay -f super
 ________________________________________
/ If Impossible is as good as beef, then \
\ Bizarro is as good as me               /
 ----------------------------------------
     \
      \   ^__^    /^^^^^^^^/
       \  (oo)  //^^^^^^^^/
          (__)\/_______/-----*
       ^______/ ___    \_______^
       ^_____/\ \S/    /--------^
               \______/	 
       
       It's a bird...
        It's a plane...
```
